@@ -5,10 +5,12 @@ from bqskit.passes.partitioning.cluster import ClusteringPartitioner
 from bqskit.passes.partitioning.greedy import GreedyPartitioner
 from bqskit.passes.partitioning.quick import QuickPartitioner
 from bqskit.passes.partitioning.scan import ScanPartitioner
+from bqskit.passes.partitioning.single import GroupSingleQuditGatePass
 
 __all__ = [
     'ClusteringPartitioner',
     'GreedyPartitioner',
     'ScanPartitioner',
     'QuickPartitioner',
+    'GroupSingleQuditGatePass',
 ]
